@@ -8,6 +8,7 @@ import SourceInfo as Source
 import ProgramOptions as Options
 import System.Environment
 import Templates
+import Control.Monad
 import Data.Time.Clock
 import Network.HTTP.Conduit
 import Network.URI
@@ -25,7 +26,7 @@ getFileContent url = do
 processSources :: Options -> String -> [SourceInfo]-> IO ()
 processSources options taskFile sources = do
         manager <- newManager tlsManagerSettings
-        (parsed, sourceInfo) <- unzip <$> mapM (parseSource manager) sources
+        (parsed, sourceInfo) <- mapAndUnzipM (parseSource manager) sources
         let parsed' = concat parsed
             sourceInfoText = showInfo sourceInfo
             optionsText = logOptions options
@@ -33,7 +34,7 @@ processSources options taskFile sources = do
         writeTask taskFile (sourceInfoText ++ optionsText) parsed'
         if null._cssDomain $ options
                 then putStrLn "WARNING: CSS generation is not run because webserver domain is not specified"
-                else elemBlock (_webDir options) sourceInfoText parsed'
+                else elemBlock (_webDir options) sourceInfoText (_debugLevel options) parsed'
         urlBlock (_privoxyDir options) sourceInfoText parsed'
         writeTemplateFiles (_privoxyDir options) (_cssDomain options) (_useHTTP options)
         putStrLn $ "Run 'adblock2privoxy -t " ++ taskFile ++ "' every 1-2 days to process data updates."
@@ -62,7 +63,7 @@ main =  do
         setForeignEncoding utf8
         now <- getCurrentTime
         args <- getArgs
-        (options@(Options printVersion _ _ taskFile _ _ forced), urls) <- parseOptions args
+        (options@(Options printVersion _ _ taskFile _ _ _ forced), urls) <- parseOptions args
         (options', task) <- do
                 fileExists <- doesFileExist taskFile
                 if fileExists
@@ -78,10 +79,12 @@ main =  do
                         Nothing -> writeError "no input specified"
                         (Just task') -> do
                                 let sources = Source.readLogInfos task'
-                                if forced || or (infoExpired now <$> sources)
+                                if forced || any (infoExpired now) sources
                                         then processSources options' taskFile sources
                                         else putStrLn "all sources are up to date"
-
+            debug = _debugLevel options
+        when (debug > DebugLevel 0) $
+            putStrLn $ concat ["Debug level '", show debug, "'."]
         action
         now' <- getCurrentTime
         putStrLn $ concat ["Execution done in ", show $ diffUTCTime now' now, " seconds."]
